Module persistent_topic_api

Module persistent_topic_api 

Enums

PersistentTopicsAnalyzeSubscriptionBacklogError
struct for typed errors of method persistent_topics_analyze_subscription_backlog
PersistentTopicsCompactError
struct for typed errors of method persistent_topics_compact
PersistentTopicsCompactionStatusError
struct for typed errors of method persistent_topics_compaction_status
PersistentTopicsCreateMissedPartitionsError
struct for typed errors of method persistent_topics_create_missed_partitions
PersistentTopicsCreateNonPartitionedTopicError
struct for typed errors of method persistent_topics_create_non_partitioned_topic
PersistentTopicsCreatePartitionedTopicError
struct for typed errors of method persistent_topics_create_partitioned_topic
PersistentTopicsCreateSubscriptionError
struct for typed errors of method persistent_topics_create_subscription
PersistentTopicsDeleteDeduplicationSnapshotIntervalError
struct for typed errors of method persistent_topics_delete_deduplication_snapshot_interval
PersistentTopicsDeleteDelayedDeliveryPoliciesError
struct for typed errors of method persistent_topics_delete_delayed_delivery_policies
PersistentTopicsDeleteInactiveTopicPoliciesError
struct for typed errors of method persistent_topics_delete_inactive_topic_policies
PersistentTopicsDeleteMaxUnackedMessagesOnConsumerError
struct for typed errors of method persistent_topics_delete_max_unacked_messages_on_consumer
PersistentTopicsDeleteMaxUnackedMessagesOnSubscriptionError
struct for typed errors of method persistent_topics_delete_max_unacked_messages_on_subscription
PersistentTopicsDeletePartitionedTopicError
struct for typed errors of method persistent_topics_delete_partitioned_topic
PersistentTopicsDeleteShadowTopicsError
struct for typed errors of method persistent_topics_delete_shadow_topics
PersistentTopicsDeleteSubscriptionError
struct for typed errors of method persistent_topics_delete_subscription
PersistentTopicsDeleteTopicError
struct for typed errors of method persistent_topics_delete_topic
PersistentTopicsExamineMessageError
struct for typed errors of method persistent_topics_examine_message
PersistentTopicsExpireMessagesForAllSubscriptionsError
struct for typed errors of method persistent_topics_expire_messages_for_all_subscriptions
PersistentTopicsExpireTopicMessages0Error
struct for typed errors of method persistent_topics_expire_topic_messages_0
PersistentTopicsExpireTopicMessagesError
struct for typed errors of method persistent_topics_expire_topic_messages
PersistentTopicsGetAutoSubscriptionCreationError
struct for typed errors of method persistent_topics_get_auto_subscription_creation
PersistentTopicsGetBacklogError
struct for typed errors of method persistent_topics_get_backlog
PersistentTopicsGetBacklogQuotaMapError
struct for typed errors of method persistent_topics_get_backlog_quota_map
PersistentTopicsGetBacklogSizeByMessageIdError
struct for typed errors of method persistent_topics_get_backlog_size_by_message_id
PersistentTopicsGetCompactionThresholdError
struct for typed errors of method persistent_topics_get_compaction_threshold
PersistentTopicsGetDeduplicationError
struct for typed errors of method persistent_topics_get_deduplication
PersistentTopicsGetDeduplicationSnapshotIntervalError
struct for typed errors of method persistent_topics_get_deduplication_snapshot_interval
PersistentTopicsGetDelayedDeliveryPoliciesError
struct for typed errors of method persistent_topics_get_delayed_delivery_policies
PersistentTopicsGetDispatchRateError
struct for typed errors of method persistent_topics_get_dispatch_rate
PersistentTopicsGetDispatcherPauseOnAckStatePersistentError
struct for typed errors of method persistent_topics_get_dispatcher_pause_on_ack_state_persistent
PersistentTopicsGetEntryFiltersError
struct for typed errors of method persistent_topics_get_entry_filters
PersistentTopicsGetInactiveTopicPoliciesError
struct for typed errors of method persistent_topics_get_inactive_topic_policies
PersistentTopicsGetInternalStatsError
struct for typed errors of method persistent_topics_get_internal_stats
PersistentTopicsGetLastMessageIdError
struct for typed errors of method persistent_topics_get_last_message_id
PersistentTopicsGetListError
struct for typed errors of method persistent_topics_get_list
PersistentTopicsGetManagedLedgerInfoError
struct for typed errors of method persistent_topics_get_managed_ledger_info
PersistentTopicsGetMaxConsumersError
struct for typed errors of method persistent_topics_get_max_consumers
PersistentTopicsGetMaxConsumersPerSubscriptionError
struct for typed errors of method persistent_topics_get_max_consumers_per_subscription
PersistentTopicsGetMaxMessageSizeError
struct for typed errors of method persistent_topics_get_max_message_size
PersistentTopicsGetMaxProducersError
struct for typed errors of method persistent_topics_get_max_producers
PersistentTopicsGetMaxSubscriptionsPerTopicError
struct for typed errors of method persistent_topics_get_max_subscriptions_per_topic
PersistentTopicsGetMaxUnackedMessagesOnConsumerError
struct for typed errors of method persistent_topics_get_max_unacked_messages_on_consumer
PersistentTopicsGetMaxUnackedMessagesOnSubscriptionError
struct for typed errors of method persistent_topics_get_max_unacked_messages_on_subscription
PersistentTopicsGetMessageByIdError
struct for typed errors of method persistent_topics_get_message_by_id
PersistentTopicsGetMessageIdByTimestampError
struct for typed errors of method persistent_topics_get_message_id_by_timestamp
PersistentTopicsGetMessageTtlError
struct for typed errors of method persistent_topics_get_message_ttl
PersistentTopicsGetOffloadPoliciesError
struct for typed errors of method persistent_topics_get_offload_policies
PersistentTopicsGetPartitionedMetadataError
struct for typed errors of method persistent_topics_get_partitioned_metadata
PersistentTopicsGetPartitionedStatsError
struct for typed errors of method persistent_topics_get_partitioned_stats
PersistentTopicsGetPartitionedStatsInternalError
struct for typed errors of method persistent_topics_get_partitioned_stats_internal
PersistentTopicsGetPartitionedTopicListError
struct for typed errors of method persistent_topics_get_partitioned_topic_list
PersistentTopicsGetPermissionsOnTopicError
struct for typed errors of method persistent_topics_get_permissions_on_topic
PersistentTopicsGetPersistenceError
struct for typed errors of method persistent_topics_get_persistence
PersistentTopicsGetPropertiesError
struct for typed errors of method persistent_topics_get_properties
PersistentTopicsGetPublishRateError
struct for typed errors of method persistent_topics_get_publish_rate
PersistentTopicsGetReplicatedSubscriptionStatusError
struct for typed errors of method persistent_topics_get_replicated_subscription_status
PersistentTopicsGetReplicationClustersError
struct for typed errors of method persistent_topics_get_replication_clusters
PersistentTopicsGetReplicatorDispatchRateError
struct for typed errors of method persistent_topics_get_replicator_dispatch_rate
PersistentTopicsGetRetentionError
struct for typed errors of method persistent_topics_get_retention
PersistentTopicsGetSchemaCompatibilityStrategyError
struct for typed errors of method persistent_topics_get_schema_compatibility_strategy
PersistentTopicsGetSchemaValidationEnforcedError
struct for typed errors of method persistent_topics_get_schema_validation_enforced
PersistentTopicsGetShadowTopicsError
struct for typed errors of method persistent_topics_get_shadow_topics
PersistentTopicsGetStatsError
struct for typed errors of method persistent_topics_get_stats
PersistentTopicsGetSubscribeRateError
struct for typed errors of method persistent_topics_get_subscribe_rate
PersistentTopicsGetSubscriptionDispatchRateError
struct for typed errors of method persistent_topics_get_subscription_dispatch_rate
PersistentTopicsGetSubscriptionLevelDispatchRateError
struct for typed errors of method persistent_topics_get_subscription_level_dispatch_rate
PersistentTopicsGetSubscriptionPropertiesError
struct for typed errors of method persistent_topics_get_subscription_properties
PersistentTopicsGetSubscriptionTypesEnabledError
struct for typed errors of method persistent_topics_get_subscription_types_enabled
PersistentTopicsGetSubscriptionsError
struct for typed errors of method persistent_topics_get_subscriptions
PersistentTopicsGrantPermissionsOnTopicError
struct for typed errors of method persistent_topics_grant_permissions_on_topic
PersistentTopicsOffloadStatusError
struct for typed errors of method persistent_topics_offload_status
PersistentTopicsPeekNthMessageError
struct for typed errors of method persistent_topics_peek_nth_message
PersistentTopicsRemoveAutoSubscriptionCreationError
struct for typed errors of method persistent_topics_remove_auto_subscription_creation
PersistentTopicsRemoveBacklogQuotaError
struct for typed errors of method persistent_topics_remove_backlog_quota
PersistentTopicsRemoveCompactionThresholdError
struct for typed errors of method persistent_topics_remove_compaction_threshold
PersistentTopicsRemoveDeduplicationError
struct for typed errors of method persistent_topics_remove_deduplication
PersistentTopicsRemoveDispatchRateError
struct for typed errors of method persistent_topics_remove_dispatch_rate
PersistentTopicsRemoveDispatcherPauseOnAckStatePersistentError
struct for typed errors of method persistent_topics_remove_dispatcher_pause_on_ack_state_persistent
PersistentTopicsRemoveEntryFiltersError
struct for typed errors of method persistent_topics_remove_entry_filters
PersistentTopicsRemoveMaxConsumersError
struct for typed errors of method persistent_topics_remove_max_consumers
PersistentTopicsRemoveMaxConsumersPerSubscriptionError
struct for typed errors of method persistent_topics_remove_max_consumers_per_subscription
PersistentTopicsRemoveMaxMessageSizeError
struct for typed errors of method persistent_topics_remove_max_message_size
PersistentTopicsRemoveMaxProducersError
struct for typed errors of method persistent_topics_remove_max_producers
PersistentTopicsRemoveMaxSubscriptionsPerTopicError
struct for typed errors of method persistent_topics_remove_max_subscriptions_per_topic
PersistentTopicsRemoveMessageTtlError
struct for typed errors of method persistent_topics_remove_message_ttl
PersistentTopicsRemoveOffloadPoliciesError
struct for typed errors of method persistent_topics_remove_offload_policies
PersistentTopicsRemovePersistenceError
struct for typed errors of method persistent_topics_remove_persistence
PersistentTopicsRemovePropertiesError
struct for typed errors of method persistent_topics_remove_properties
PersistentTopicsRemovePublishRateError
struct for typed errors of method persistent_topics_remove_publish_rate
PersistentTopicsRemoveReplicationClustersError
struct for typed errors of method persistent_topics_remove_replication_clusters
PersistentTopicsRemoveReplicatorDispatchRateError
struct for typed errors of method persistent_topics_remove_replicator_dispatch_rate
PersistentTopicsRemoveRetentionError
struct for typed errors of method persistent_topics_remove_retention
PersistentTopicsRemoveSchemaCompatibilityStrategyError
struct for typed errors of method persistent_topics_remove_schema_compatibility_strategy
PersistentTopicsRemoveSubscribeRateError
struct for typed errors of method persistent_topics_remove_subscribe_rate
PersistentTopicsRemoveSubscriptionDispatchRateError
struct for typed errors of method persistent_topics_remove_subscription_dispatch_rate
PersistentTopicsRemoveSubscriptionLevelDispatchRateError
struct for typed errors of method persistent_topics_remove_subscription_level_dispatch_rate
PersistentTopicsRemoveSubscriptionTypesEnabledError
struct for typed errors of method persistent_topics_remove_subscription_types_enabled
PersistentTopicsResetCursorError
struct for typed errors of method persistent_topics_reset_cursor
PersistentTopicsResetCursorOnPositionError
struct for typed errors of method persistent_topics_reset_cursor_on_position
PersistentTopicsRevokePermissionsOnTopicError
struct for typed errors of method persistent_topics_revoke_permissions_on_topic
PersistentTopicsSetAutoSubscriptionCreationError
struct for typed errors of method persistent_topics_set_auto_subscription_creation
PersistentTopicsSetBacklogQuotaError
struct for typed errors of method persistent_topics_set_backlog_quota
PersistentTopicsSetCompactionThresholdError
struct for typed errors of method persistent_topics_set_compaction_threshold
PersistentTopicsSetDeduplicationError
struct for typed errors of method persistent_topics_set_deduplication
PersistentTopicsSetDeduplicationSnapshotIntervalError
struct for typed errors of method persistent_topics_set_deduplication_snapshot_interval
PersistentTopicsSetDelayedDeliveryPoliciesError
struct for typed errors of method persistent_topics_set_delayed_delivery_policies
PersistentTopicsSetDispatchRateError
struct for typed errors of method persistent_topics_set_dispatch_rate
PersistentTopicsSetDispatcherPauseOnAckStatePersistentError
struct for typed errors of method persistent_topics_set_dispatcher_pause_on_ack_state_persistent
PersistentTopicsSetEntryFiltersError
struct for typed errors of method persistent_topics_set_entry_filters
PersistentTopicsSetInactiveTopicPoliciesError
struct for typed errors of method persistent_topics_set_inactive_topic_policies
PersistentTopicsSetMaxConsumersError
struct for typed errors of method persistent_topics_set_max_consumers
PersistentTopicsSetMaxConsumersPerSubscriptionError
struct for typed errors of method persistent_topics_set_max_consumers_per_subscription
PersistentTopicsSetMaxMessageSizeError
struct for typed errors of method persistent_topics_set_max_message_size
PersistentTopicsSetMaxProducersError
struct for typed errors of method persistent_topics_set_max_producers
PersistentTopicsSetMaxSubscriptionsPerTopicError
struct for typed errors of method persistent_topics_set_max_subscriptions_per_topic
PersistentTopicsSetMaxUnackedMessagesOnConsumerError
struct for typed errors of method persistent_topics_set_max_unacked_messages_on_consumer
PersistentTopicsSetMaxUnackedMessagesOnSubscriptionError
struct for typed errors of method persistent_topics_set_max_unacked_messages_on_subscription
PersistentTopicsSetMessageTtlError
struct for typed errors of method persistent_topics_set_message_ttl
PersistentTopicsSetOffloadPoliciesError
struct for typed errors of method persistent_topics_set_offload_policies
PersistentTopicsSetPersistenceError
struct for typed errors of method persistent_topics_set_persistence
PersistentTopicsSetPublishRateError
struct for typed errors of method persistent_topics_set_publish_rate
PersistentTopicsSetReplicatedSubscriptionStatusError
struct for typed errors of method persistent_topics_set_replicated_subscription_status
PersistentTopicsSetReplicationClustersError
struct for typed errors of method persistent_topics_set_replication_clusters
PersistentTopicsSetReplicatorDispatchRateError
struct for typed errors of method persistent_topics_set_replicator_dispatch_rate
PersistentTopicsSetRetentionError
struct for typed errors of method persistent_topics_set_retention
PersistentTopicsSetSchemaCompatibilityStrategyError
struct for typed errors of method persistent_topics_set_schema_compatibility_strategy
PersistentTopicsSetSchemaValidationEnforcedError
struct for typed errors of method persistent_topics_set_schema_validation_enforced
PersistentTopicsSetShadowTopicsError
struct for typed errors of method persistent_topics_set_shadow_topics
PersistentTopicsSetSubscribeRateError
struct for typed errors of method persistent_topics_set_subscribe_rate
PersistentTopicsSetSubscriptionDispatchRateError
struct for typed errors of method persistent_topics_set_subscription_dispatch_rate
PersistentTopicsSetSubscriptionLevelDispatchRateError
struct for typed errors of method persistent_topics_set_subscription_level_dispatch_rate
PersistentTopicsSetSubscriptionTypesEnabledError
struct for typed errors of method persistent_topics_set_subscription_types_enabled
PersistentTopicsSkipAllMessagesError
struct for typed errors of method persistent_topics_skip_all_messages
PersistentTopicsSkipMessagesError
struct for typed errors of method persistent_topics_skip_messages
PersistentTopicsTerminateError
struct for typed errors of method persistent_topics_terminate
PersistentTopicsTerminatePartitionedTopicError
struct for typed errors of method persistent_topics_terminate_partitioned_topic
PersistentTopicsTriggerOffloadError
struct for typed errors of method persistent_topics_trigger_offload
PersistentTopicsTrimTopicError
struct for typed errors of method persistent_topics_trim_topic
PersistentTopicsTruncateTopicError
struct for typed errors of method persistent_topics_truncate_topic
PersistentTopicsUnloadTopicError
struct for typed errors of method persistent_topics_unload_topic
PersistentTopicsUpdatePartitionedTopicError
struct for typed errors of method persistent_topics_update_partitioned_topic
PersistentTopicsUpdatePropertiesError
struct for typed errors of method persistent_topics_update_properties
PersistentTopicsUpdateSubscriptionPropertiesError
struct for typed errors of method persistent_topics_update_subscription_properties

Functions

persistent_topics_analyze_subscription_backlog
persistent_topics_compact
persistent_topics_compaction_status
persistent_topics_create_missed_partitions
persistent_topics_create_non_partitioned_topic
This is the only REST endpoint from which non-partitioned topics could be created.
persistent_topics_create_partitioned_topic
It needs to be called before creating a producer on a partitioned topic.
persistent_topics_create_subscription
Creates a subscription on the topic at the specified message id
persistent_topics_delete_deduplication_snapshot_interval
persistent_topics_delete_delayed_delivery_policies
persistent_topics_delete_inactive_topic_policies
persistent_topics_delete_max_unacked_messages_on_consumer
persistent_topics_delete_max_unacked_messages_on_subscription
persistent_topics_delete_partitioned_topic
It will also delete all the partitions of the topic if it exists.
persistent_topics_delete_shadow_topics
persistent_topics_delete_subscription
The subscription cannot be deleted if delete is not forcefully and there are any active consumers attached to it. Force delete ignores connected consumers and deletes subscription by explicitly closing them.
persistent_topics_delete_topic
The topic cannot be deleted if delete is not forcefully and there’s any active subscription or producer connected to the it. Force delete ignores connected clients and deletes topic by explicitly closing them.
persistent_topics_examine_message
persistent_topics_expire_messages_for_all_subscriptions
persistent_topics_expire_topic_messages
persistent_topics_expire_topic_messages_0
persistent_topics_get_auto_subscription_creation
persistent_topics_get_backlog
persistent_topics_get_backlog_quota_map
persistent_topics_get_backlog_size_by_message_id
persistent_topics_get_compaction_threshold
persistent_topics_get_deduplication
persistent_topics_get_deduplication_snapshot_interval
persistent_topics_get_delayed_delivery_policies
persistent_topics_get_dispatch_rate
persistent_topics_get_dispatcher_pause_on_ack_state_persistent
persistent_topics_get_entry_filters
persistent_topics_get_inactive_topic_policies
persistent_topics_get_internal_stats
persistent_topics_get_last_message_id
persistent_topics_get_list
persistent_topics_get_managed_ledger_info
persistent_topics_get_max_consumers
persistent_topics_get_max_consumers_per_subscription
persistent_topics_get_max_message_size
persistent_topics_get_max_producers
persistent_topics_get_max_subscriptions_per_topic
persistent_topics_get_max_unacked_messages_on_consumer
persistent_topics_get_max_unacked_messages_on_subscription
persistent_topics_get_message_by_id
persistent_topics_get_message_id_by_timestamp
persistent_topics_get_message_ttl
persistent_topics_get_offload_policies
persistent_topics_get_partitioned_metadata
persistent_topics_get_partitioned_stats
persistent_topics_get_partitioned_stats_internal
persistent_topics_get_partitioned_topic_list
persistent_topics_get_permissions_on_topic
Retrieve the effective permissions for a topic. These permissions are defined by the permissions set at thenamespace level combined (union) with any eventual specific permission set on the topic.
persistent_topics_get_persistence
persistent_topics_get_properties
persistent_topics_get_publish_rate
persistent_topics_get_replicated_subscription_status
persistent_topics_get_replication_clusters
persistent_topics_get_replicator_dispatch_rate
persistent_topics_get_retention
persistent_topics_get_schema_compatibility_strategy
persistent_topics_get_schema_validation_enforced
persistent_topics_get_shadow_topics
persistent_topics_get_stats
persistent_topics_get_subscribe_rate
persistent_topics_get_subscription_dispatch_rate
persistent_topics_get_subscription_level_dispatch_rate
persistent_topics_get_subscription_properties
persistent_topics_get_subscription_types_enabled
persistent_topics_get_subscriptions
persistent_topics_grant_permissions_on_topic
persistent_topics_offload_status
persistent_topics_peek_nth_message
persistent_topics_remove_auto_subscription_creation
persistent_topics_remove_backlog_quota
persistent_topics_remove_compaction_threshold
persistent_topics_remove_deduplication
persistent_topics_remove_dispatch_rate
persistent_topics_remove_dispatcher_pause_on_ack_state_persistent
persistent_topics_remove_entry_filters
persistent_topics_remove_max_consumers
persistent_topics_remove_max_consumers_per_subscription
persistent_topics_remove_max_message_size
persistent_topics_remove_max_producers
persistent_topics_remove_max_subscriptions_per_topic
persistent_topics_remove_message_ttl
persistent_topics_remove_offload_policies
persistent_topics_remove_persistence
persistent_topics_remove_properties
persistent_topics_remove_publish_rate
persistent_topics_remove_replication_clusters
persistent_topics_remove_replicator_dispatch_rate
persistent_topics_remove_retention
persistent_topics_remove_schema_compatibility_strategy
persistent_topics_remove_subscribe_rate
persistent_topics_remove_subscription_dispatch_rate
persistent_topics_remove_subscription_level_dispatch_rate
persistent_topics_remove_subscription_types_enabled
persistent_topics_reset_cursor
It fence cursor and disconnects all active consumers before resetting cursor.
persistent_topics_reset_cursor_on_position
It fence cursor and disconnects all active consumers before resetting cursor.
persistent_topics_revoke_permissions_on_topic
Revoke permissions to a role on a single topic. If the permission was not set at the topiclevel, but rather at the namespace level, this operation will return an error (HTTP status code 412).
persistent_topics_set_auto_subscription_creation
persistent_topics_set_backlog_quota
persistent_topics_set_compaction_threshold
persistent_topics_set_deduplication
persistent_topics_set_deduplication_snapshot_interval
persistent_topics_set_delayed_delivery_policies
persistent_topics_set_dispatch_rate
persistent_topics_set_dispatcher_pause_on_ack_state_persistent
persistent_topics_set_entry_filters
persistent_topics_set_inactive_topic_policies
persistent_topics_set_max_consumers
persistent_topics_set_max_consumers_per_subscription
persistent_topics_set_max_message_size
persistent_topics_set_max_producers
persistent_topics_set_max_subscriptions_per_topic
persistent_topics_set_max_unacked_messages_on_consumer
persistent_topics_set_max_unacked_messages_on_subscription
persistent_topics_set_message_ttl
persistent_topics_set_offload_policies
persistent_topics_set_persistence
persistent_topics_set_publish_rate
persistent_topics_set_replicated_subscription_status
persistent_topics_set_replication_clusters
persistent_topics_set_replicator_dispatch_rate
persistent_topics_set_retention
persistent_topics_set_schema_compatibility_strategy
persistent_topics_set_schema_validation_enforced
persistent_topics_set_shadow_topics
persistent_topics_set_subscribe_rate
persistent_topics_set_subscription_dispatch_rate
persistent_topics_set_subscription_level_dispatch_rate
persistent_topics_set_subscription_types_enabled
persistent_topics_skip_all_messages
Completely clears the backlog on the subscription.
persistent_topics_skip_messages
persistent_topics_terminate
persistent_topics_terminate_partitioned_topic
persistent_topics_trigger_offload
persistent_topics_trim_topic
persistent_topics_truncate_topic
The truncate operation will move all cursors to the end of the topic and delete all inactive ledgers.
persistent_topics_unload_topic
persistent_topics_update_partitioned_topic
It increments partitions of existing partitioned-topic
persistent_topics_update_properties
persistent_topics_update_subscription_properties