Enums
- Persistent
Topics Analyze Subscription Backlog Error - struct for typed errors of method
persistent_topics_analyze_subscription_backlog - Persistent
Topics Compact Error - struct for typed errors of method
persistent_topics_compact - Persistent
Topics Compaction Status Error - struct for typed errors of method
persistent_topics_compaction_status - Persistent
Topics Create Missed Partitions Error - struct for typed errors of method
persistent_topics_create_missed_partitions - Persistent
Topics Create NonPartitioned Topic Error - struct for typed errors of method
persistent_topics_create_non_partitioned_topic - Persistent
Topics Create Partitioned Topic Error - struct for typed errors of method
persistent_topics_create_partitioned_topic - Persistent
Topics Create Subscription Error - struct for typed errors of method
persistent_topics_create_subscription - Persistent
Topics Delete Deduplication Snapshot Interval Error - struct for typed errors of method
persistent_topics_delete_deduplication_snapshot_interval - Persistent
Topics Delete Delayed Delivery Policies Error - struct for typed errors of method
persistent_topics_delete_delayed_delivery_policies - Persistent
Topics Delete Inactive Topic Policies Error - struct for typed errors of method
persistent_topics_delete_inactive_topic_policies - Persistent
Topics Delete MaxUnacked Messages OnConsumer Error - struct for typed errors of method
persistent_topics_delete_max_unacked_messages_on_consumer - Persistent
Topics Delete MaxUnacked Messages OnSubscription Error - struct for typed errors of method
persistent_topics_delete_max_unacked_messages_on_subscription - Persistent
Topics Delete Partitioned Topic Error - struct for typed errors of method
persistent_topics_delete_partitioned_topic - Persistent
Topics Delete Shadow Topics Error - struct for typed errors of method
persistent_topics_delete_shadow_topics - Persistent
Topics Delete Subscription Error - struct for typed errors of method
persistent_topics_delete_subscription - Persistent
Topics Delete Topic Error - struct for typed errors of method
persistent_topics_delete_topic - Persistent
Topics Examine Message Error - struct for typed errors of method
persistent_topics_examine_message - Persistent
Topics Expire Messages ForAll Subscriptions Error - struct for typed errors of method
persistent_topics_expire_messages_for_all_subscriptions - Persistent
Topics Expire Topic Messages0 Error - struct for typed errors of method
persistent_topics_expire_topic_messages_0 - Persistent
Topics Expire Topic Messages Error - struct for typed errors of method
persistent_topics_expire_topic_messages - Persistent
Topics GetAuto Subscription Creation Error - struct for typed errors of method
persistent_topics_get_auto_subscription_creation - Persistent
Topics GetBacklog Error - struct for typed errors of method
persistent_topics_get_backlog - Persistent
Topics GetBacklog Quota MapError - struct for typed errors of method
persistent_topics_get_backlog_quota_map - Persistent
Topics GetBacklog Size ByMessage IdError - struct for typed errors of method
persistent_topics_get_backlog_size_by_message_id - Persistent
Topics GetCompaction Threshold Error - struct for typed errors of method
persistent_topics_get_compaction_threshold - Persistent
Topics GetDeduplication Error - struct for typed errors of method
persistent_topics_get_deduplication - Persistent
Topics GetDeduplication Snapshot Interval Error - struct for typed errors of method
persistent_topics_get_deduplication_snapshot_interval - Persistent
Topics GetDelayed Delivery Policies Error - struct for typed errors of method
persistent_topics_get_delayed_delivery_policies - Persistent
Topics GetDispatch Rate Error - struct for typed errors of method
persistent_topics_get_dispatch_rate - Persistent
Topics GetDispatcher Pause OnAck State Persistent Error - struct for typed errors of method
persistent_topics_get_dispatcher_pause_on_ack_state_persistent - Persistent
Topics GetEntry Filters Error - struct for typed errors of method
persistent_topics_get_entry_filters - Persistent
Topics GetInactive Topic Policies Error - struct for typed errors of method
persistent_topics_get_inactive_topic_policies - Persistent
Topics GetInternal Stats Error - struct for typed errors of method
persistent_topics_get_internal_stats - Persistent
Topics GetLast Message IdError - struct for typed errors of method
persistent_topics_get_last_message_id - Persistent
Topics GetList Error - struct for typed errors of method
persistent_topics_get_list - Persistent
Topics GetManaged Ledger Info Error - struct for typed errors of method
persistent_topics_get_managed_ledger_info - Persistent
Topics GetMax Consumers Error - struct for typed errors of method
persistent_topics_get_max_consumers - Persistent
Topics GetMax Consumers PerSubscription Error - struct for typed errors of method
persistent_topics_get_max_consumers_per_subscription - Persistent
Topics GetMax Message Size Error - struct for typed errors of method
persistent_topics_get_max_message_size - Persistent
Topics GetMax Producers Error - struct for typed errors of method
persistent_topics_get_max_producers - Persistent
Topics GetMax Subscriptions PerTopic Error - struct for typed errors of method
persistent_topics_get_max_subscriptions_per_topic - Persistent
Topics GetMax Unacked Messages OnConsumer Error - struct for typed errors of method
persistent_topics_get_max_unacked_messages_on_consumer - Persistent
Topics GetMax Unacked Messages OnSubscription Error - struct for typed errors of method
persistent_topics_get_max_unacked_messages_on_subscription - Persistent
Topics GetMessage ById Error - struct for typed errors of method
persistent_topics_get_message_by_id - Persistent
Topics GetMessage IdBy Timestamp Error - struct for typed errors of method
persistent_topics_get_message_id_by_timestamp - Persistent
Topics GetMessage TtlError - struct for typed errors of method
persistent_topics_get_message_ttl - Persistent
Topics GetOffload Policies Error - struct for typed errors of method
persistent_topics_get_offload_policies - Persistent
Topics GetPartitioned Metadata Error - struct for typed errors of method
persistent_topics_get_partitioned_metadata - Persistent
Topics GetPartitioned Stats Error - struct for typed errors of method
persistent_topics_get_partitioned_stats - Persistent
Topics GetPartitioned Stats Internal Error - struct for typed errors of method
persistent_topics_get_partitioned_stats_internal - Persistent
Topics GetPartitioned Topic List Error - struct for typed errors of method
persistent_topics_get_partitioned_topic_list - Persistent
Topics GetPermissions OnTopic Error - struct for typed errors of method
persistent_topics_get_permissions_on_topic - Persistent
Topics GetPersistence Error - struct for typed errors of method
persistent_topics_get_persistence - Persistent
Topics GetProperties Error - struct for typed errors of method
persistent_topics_get_properties - Persistent
Topics GetPublish Rate Error - struct for typed errors of method
persistent_topics_get_publish_rate - Persistent
Topics GetReplicated Subscription Status Error - struct for typed errors of method
persistent_topics_get_replicated_subscription_status - Persistent
Topics GetReplication Clusters Error - struct for typed errors of method
persistent_topics_get_replication_clusters - Persistent
Topics GetReplicator Dispatch Rate Error - struct for typed errors of method
persistent_topics_get_replicator_dispatch_rate - Persistent
Topics GetRetention Error - struct for typed errors of method
persistent_topics_get_retention - Persistent
Topics GetSchema Compatibility Strategy Error - struct for typed errors of method
persistent_topics_get_schema_compatibility_strategy - Persistent
Topics GetSchema Validation Enforced Error - struct for typed errors of method
persistent_topics_get_schema_validation_enforced - Persistent
Topics GetShadow Topics Error - struct for typed errors of method
persistent_topics_get_shadow_topics - Persistent
Topics GetStats Error - struct for typed errors of method
persistent_topics_get_stats - Persistent
Topics GetSubscribe Rate Error - struct for typed errors of method
persistent_topics_get_subscribe_rate - Persistent
Topics GetSubscription Dispatch Rate Error - struct for typed errors of method
persistent_topics_get_subscription_dispatch_rate - Persistent
Topics GetSubscription Level Dispatch Rate Error - struct for typed errors of method
persistent_topics_get_subscription_level_dispatch_rate - Persistent
Topics GetSubscription Properties Error - struct for typed errors of method
persistent_topics_get_subscription_properties - Persistent
Topics GetSubscription Types Enabled Error - struct for typed errors of method
persistent_topics_get_subscription_types_enabled - Persistent
Topics GetSubscriptions Error - struct for typed errors of method
persistent_topics_get_subscriptions - Persistent
Topics Grant Permissions OnTopic Error - struct for typed errors of method
persistent_topics_grant_permissions_on_topic - Persistent
Topics Offload Status Error - struct for typed errors of method
persistent_topics_offload_status - Persistent
Topics Peek NthMessage Error - struct for typed errors of method
persistent_topics_peek_nth_message - Persistent
Topics Remove Auto Subscription Creation Error - struct for typed errors of method
persistent_topics_remove_auto_subscription_creation - Persistent
Topics Remove Backlog Quota Error - struct for typed errors of method
persistent_topics_remove_backlog_quota - Persistent
Topics Remove Compaction Threshold Error - struct for typed errors of method
persistent_topics_remove_compaction_threshold - Persistent
Topics Remove Deduplication Error - struct for typed errors of method
persistent_topics_remove_deduplication - Persistent
Topics Remove Dispatch Rate Error - struct for typed errors of method
persistent_topics_remove_dispatch_rate - Persistent
Topics Remove Dispatcher Pause OnAck State Persistent Error - struct for typed errors of method
persistent_topics_remove_dispatcher_pause_on_ack_state_persistent - Persistent
Topics Remove Entry Filters Error - struct for typed errors of method
persistent_topics_remove_entry_filters - Persistent
Topics Remove MaxConsumers Error - struct for typed errors of method
persistent_topics_remove_max_consumers - Persistent
Topics Remove MaxConsumers PerSubscription Error - struct for typed errors of method
persistent_topics_remove_max_consumers_per_subscription - Persistent
Topics Remove MaxMessage Size Error - struct for typed errors of method
persistent_topics_remove_max_message_size - Persistent
Topics Remove MaxProducers Error - struct for typed errors of method
persistent_topics_remove_max_producers - Persistent
Topics Remove MaxSubscriptions PerTopic Error - struct for typed errors of method
persistent_topics_remove_max_subscriptions_per_topic - Persistent
Topics Remove Message TtlError - struct for typed errors of method
persistent_topics_remove_message_ttl - Persistent
Topics Remove Offload Policies Error - struct for typed errors of method
persistent_topics_remove_offload_policies - Persistent
Topics Remove Persistence Error - struct for typed errors of method
persistent_topics_remove_persistence - Persistent
Topics Remove Properties Error - struct for typed errors of method
persistent_topics_remove_properties - Persistent
Topics Remove Publish Rate Error - struct for typed errors of method
persistent_topics_remove_publish_rate - Persistent
Topics Remove Replication Clusters Error - struct for typed errors of method
persistent_topics_remove_replication_clusters - Persistent
Topics Remove Replicator Dispatch Rate Error - struct for typed errors of method
persistent_topics_remove_replicator_dispatch_rate - Persistent
Topics Remove Retention Error - struct for typed errors of method
persistent_topics_remove_retention - Persistent
Topics Remove Schema Compatibility Strategy Error - struct for typed errors of method
persistent_topics_remove_schema_compatibility_strategy - Persistent
Topics Remove Subscribe Rate Error - struct for typed errors of method
persistent_topics_remove_subscribe_rate - Persistent
Topics Remove Subscription Dispatch Rate Error - struct for typed errors of method
persistent_topics_remove_subscription_dispatch_rate - Persistent
Topics Remove Subscription Level Dispatch Rate Error - struct for typed errors of method
persistent_topics_remove_subscription_level_dispatch_rate - Persistent
Topics Remove Subscription Types Enabled Error - struct for typed errors of method
persistent_topics_remove_subscription_types_enabled - Persistent
Topics Reset Cursor Error - struct for typed errors of method
persistent_topics_reset_cursor - Persistent
Topics Reset Cursor OnPosition Error - struct for typed errors of method
persistent_topics_reset_cursor_on_position - Persistent
Topics Revoke Permissions OnTopic Error - struct for typed errors of method
persistent_topics_revoke_permissions_on_topic - Persistent
Topics SetAuto Subscription Creation Error - struct for typed errors of method
persistent_topics_set_auto_subscription_creation - Persistent
Topics SetBacklog Quota Error - struct for typed errors of method
persistent_topics_set_backlog_quota - Persistent
Topics SetCompaction Threshold Error - struct for typed errors of method
persistent_topics_set_compaction_threshold - Persistent
Topics SetDeduplication Error - struct for typed errors of method
persistent_topics_set_deduplication - Persistent
Topics SetDeduplication Snapshot Interval Error - struct for typed errors of method
persistent_topics_set_deduplication_snapshot_interval - Persistent
Topics SetDelayed Delivery Policies Error - struct for typed errors of method
persistent_topics_set_delayed_delivery_policies - Persistent
Topics SetDispatch Rate Error - struct for typed errors of method
persistent_topics_set_dispatch_rate - Persistent
Topics SetDispatcher Pause OnAck State Persistent Error - struct for typed errors of method
persistent_topics_set_dispatcher_pause_on_ack_state_persistent - Persistent
Topics SetEntry Filters Error - struct for typed errors of method
persistent_topics_set_entry_filters - Persistent
Topics SetInactive Topic Policies Error - struct for typed errors of method
persistent_topics_set_inactive_topic_policies - Persistent
Topics SetMax Consumers Error - struct for typed errors of method
persistent_topics_set_max_consumers - Persistent
Topics SetMax Consumers PerSubscription Error - struct for typed errors of method
persistent_topics_set_max_consumers_per_subscription - Persistent
Topics SetMax Message Size Error - struct for typed errors of method
persistent_topics_set_max_message_size - Persistent
Topics SetMax Producers Error - struct for typed errors of method
persistent_topics_set_max_producers - Persistent
Topics SetMax Subscriptions PerTopic Error - struct for typed errors of method
persistent_topics_set_max_subscriptions_per_topic - Persistent
Topics SetMax Unacked Messages OnConsumer Error - struct for typed errors of method
persistent_topics_set_max_unacked_messages_on_consumer - Persistent
Topics SetMax Unacked Messages OnSubscription Error - struct for typed errors of method
persistent_topics_set_max_unacked_messages_on_subscription - Persistent
Topics SetMessage TtlError - struct for typed errors of method
persistent_topics_set_message_ttl - Persistent
Topics SetOffload Policies Error - struct for typed errors of method
persistent_topics_set_offload_policies - Persistent
Topics SetPersistence Error - struct for typed errors of method
persistent_topics_set_persistence - Persistent
Topics SetPublish Rate Error - struct for typed errors of method
persistent_topics_set_publish_rate - Persistent
Topics SetReplicated Subscription Status Error - struct for typed errors of method
persistent_topics_set_replicated_subscription_status - Persistent
Topics SetReplication Clusters Error - struct for typed errors of method
persistent_topics_set_replication_clusters - Persistent
Topics SetReplicator Dispatch Rate Error - struct for typed errors of method
persistent_topics_set_replicator_dispatch_rate - Persistent
Topics SetRetention Error - struct for typed errors of method
persistent_topics_set_retention - Persistent
Topics SetSchema Compatibility Strategy Error - struct for typed errors of method
persistent_topics_set_schema_compatibility_strategy - Persistent
Topics SetSchema Validation Enforced Error - struct for typed errors of method
persistent_topics_set_schema_validation_enforced - Persistent
Topics SetShadow Topics Error - struct for typed errors of method
persistent_topics_set_shadow_topics - Persistent
Topics SetSubscribe Rate Error - struct for typed errors of method
persistent_topics_set_subscribe_rate - Persistent
Topics SetSubscription Dispatch Rate Error - struct for typed errors of method
persistent_topics_set_subscription_dispatch_rate - Persistent
Topics SetSubscription Level Dispatch Rate Error - struct for typed errors of method
persistent_topics_set_subscription_level_dispatch_rate - Persistent
Topics SetSubscription Types Enabled Error - struct for typed errors of method
persistent_topics_set_subscription_types_enabled - Persistent
Topics Skip AllMessages Error - struct for typed errors of method
persistent_topics_skip_all_messages - Persistent
Topics Skip Messages Error - struct for typed errors of method
persistent_topics_skip_messages - Persistent
Topics Terminate Error - struct for typed errors of method
persistent_topics_terminate - Persistent
Topics Terminate Partitioned Topic Error - struct for typed errors of method
persistent_topics_terminate_partitioned_topic - Persistent
Topics Trigger Offload Error - struct for typed errors of method
persistent_topics_trigger_offload - Persistent
Topics Trim Topic Error - struct for typed errors of method
persistent_topics_trim_topic - Persistent
Topics Truncate Topic Error - struct for typed errors of method
persistent_topics_truncate_topic - Persistent
Topics Unload Topic Error - struct for typed errors of method
persistent_topics_unload_topic - Persistent
Topics Update Partitioned Topic Error - struct for typed errors of method
persistent_topics_update_partitioned_topic - Persistent
Topics Update Properties Error - struct for typed errors of method
persistent_topics_update_properties - Persistent
Topics Update Subscription Properties Error - struct for typed errors of method
persistent_topics_update_subscription_properties
Functions
- persistent_
topics_ analyze_ subscription_ backlog - persistent_
topics_ compact - persistent_
topics_ compaction_ status - persistent_
topics_ create_ missed_ partitions - persistent_
topics_ create_ non_ partitioned_ topic - This is the only REST endpoint from which non-partitioned topics could be created.
- persistent_
topics_ create_ partitioned_ topic - It needs to be called before creating a producer on a partitioned topic.
- persistent_
topics_ create_ subscription - Creates a subscription on the topic at the specified message id
- persistent_
topics_ delete_ deduplication_ snapshot_ interval - persistent_
topics_ delete_ delayed_ delivery_ policies - persistent_
topics_ delete_ inactive_ topic_ policies - persistent_
topics_ delete_ max_ unacked_ messages_ on_ consumer - persistent_
topics_ delete_ max_ unacked_ messages_ on_ subscription - persistent_
topics_ delete_ partitioned_ topic - It will also delete all the partitions of the topic if it exists.
- persistent_
topics_ delete_ shadow_ topics - persistent_
topics_ delete_ subscription - The subscription cannot be deleted if delete is not forcefully and there are any active consumers attached to it. Force delete ignores connected consumers and deletes subscription by explicitly closing them.
- persistent_
topics_ delete_ topic - The topic cannot be deleted if delete is not forcefully and there’s any active subscription or producer connected to the it. Force delete ignores connected clients and deletes topic by explicitly closing them.
- persistent_
topics_ examine_ message - persistent_
topics_ expire_ messages_ for_ all_ subscriptions - persistent_
topics_ expire_ topic_ messages - persistent_
topics_ expire_ topic_ messages_ 0 - persistent_
topics_ get_ auto_ subscription_ creation - persistent_
topics_ get_ backlog - persistent_
topics_ get_ backlog_ quota_ map - persistent_
topics_ get_ backlog_ size_ by_ message_ id - persistent_
topics_ get_ compaction_ threshold - persistent_
topics_ get_ deduplication - persistent_
topics_ get_ deduplication_ snapshot_ interval - persistent_
topics_ get_ delayed_ delivery_ policies - persistent_
topics_ get_ dispatch_ rate - persistent_
topics_ get_ dispatcher_ pause_ on_ ack_ state_ persistent - persistent_
topics_ get_ entry_ filters - persistent_
topics_ get_ inactive_ topic_ policies - persistent_
topics_ get_ internal_ stats - persistent_
topics_ get_ last_ message_ id - persistent_
topics_ get_ list - persistent_
topics_ get_ managed_ ledger_ info - persistent_
topics_ get_ max_ consumers - persistent_
topics_ get_ max_ consumers_ per_ subscription - persistent_
topics_ get_ max_ message_ size - persistent_
topics_ get_ max_ producers - persistent_
topics_ get_ max_ subscriptions_ per_ topic - persistent_
topics_ get_ max_ unacked_ messages_ on_ consumer - persistent_
topics_ get_ max_ unacked_ messages_ on_ subscription - persistent_
topics_ get_ message_ by_ id - persistent_
topics_ get_ message_ id_ by_ timestamp - persistent_
topics_ get_ message_ ttl - persistent_
topics_ get_ offload_ policies - persistent_
topics_ get_ partitioned_ metadata - persistent_
topics_ get_ partitioned_ stats - persistent_
topics_ get_ partitioned_ stats_ internal - persistent_
topics_ get_ partitioned_ topic_ list - persistent_
topics_ get_ permissions_ on_ topic - Retrieve the effective permissions for a topic. These permissions are defined by the permissions set at thenamespace level combined (union) with any eventual specific permission set on the topic.
- persistent_
topics_ get_ persistence - persistent_
topics_ get_ properties - persistent_
topics_ get_ publish_ rate - persistent_
topics_ get_ replicated_ subscription_ status - persistent_
topics_ get_ replication_ clusters - persistent_
topics_ get_ replicator_ dispatch_ rate - persistent_
topics_ get_ retention - persistent_
topics_ get_ schema_ compatibility_ strategy - persistent_
topics_ get_ schema_ validation_ enforced - persistent_
topics_ get_ shadow_ topics - persistent_
topics_ get_ stats - persistent_
topics_ get_ subscribe_ rate - persistent_
topics_ get_ subscription_ dispatch_ rate - persistent_
topics_ get_ subscription_ level_ dispatch_ rate - persistent_
topics_ get_ subscription_ properties - persistent_
topics_ get_ subscription_ types_ enabled - persistent_
topics_ get_ subscriptions - persistent_
topics_ grant_ permissions_ on_ topic - persistent_
topics_ offload_ status - persistent_
topics_ peek_ nth_ message - persistent_
topics_ remove_ auto_ subscription_ creation - persistent_
topics_ remove_ backlog_ quota - persistent_
topics_ remove_ compaction_ threshold - persistent_
topics_ remove_ deduplication - persistent_
topics_ remove_ dispatch_ rate - persistent_
topics_ remove_ dispatcher_ pause_ on_ ack_ state_ persistent - persistent_
topics_ remove_ entry_ filters - persistent_
topics_ remove_ max_ consumers - persistent_
topics_ remove_ max_ consumers_ per_ subscription - persistent_
topics_ remove_ max_ message_ size - persistent_
topics_ remove_ max_ producers - persistent_
topics_ remove_ max_ subscriptions_ per_ topic - persistent_
topics_ remove_ message_ ttl - persistent_
topics_ remove_ offload_ policies - persistent_
topics_ remove_ persistence - persistent_
topics_ remove_ properties - persistent_
topics_ remove_ publish_ rate - persistent_
topics_ remove_ replication_ clusters - persistent_
topics_ remove_ replicator_ dispatch_ rate - persistent_
topics_ remove_ retention - persistent_
topics_ remove_ schema_ compatibility_ strategy - persistent_
topics_ remove_ subscribe_ rate - persistent_
topics_ remove_ subscription_ dispatch_ rate - persistent_
topics_ remove_ subscription_ level_ dispatch_ rate - persistent_
topics_ remove_ subscription_ types_ enabled - persistent_
topics_ reset_ cursor - It fence cursor and disconnects all active consumers before resetting cursor.
- persistent_
topics_ reset_ cursor_ on_ position - It fence cursor and disconnects all active consumers before resetting cursor.
- persistent_
topics_ revoke_ permissions_ on_ topic - Revoke permissions to a role on a single topic. If the permission was not set at the topiclevel, but rather at the namespace level, this operation will return an error (HTTP status code 412).
- persistent_
topics_ set_ auto_ subscription_ creation - persistent_
topics_ set_ backlog_ quota - persistent_
topics_ set_ compaction_ threshold - persistent_
topics_ set_ deduplication - persistent_
topics_ set_ deduplication_ snapshot_ interval - persistent_
topics_ set_ delayed_ delivery_ policies - persistent_
topics_ set_ dispatch_ rate - persistent_
topics_ set_ dispatcher_ pause_ on_ ack_ state_ persistent - persistent_
topics_ set_ entry_ filters - persistent_
topics_ set_ inactive_ topic_ policies - persistent_
topics_ set_ max_ consumers - persistent_
topics_ set_ max_ consumers_ per_ subscription - persistent_
topics_ set_ max_ message_ size - persistent_
topics_ set_ max_ producers - persistent_
topics_ set_ max_ subscriptions_ per_ topic - persistent_
topics_ set_ max_ unacked_ messages_ on_ consumer - persistent_
topics_ set_ max_ unacked_ messages_ on_ subscription - persistent_
topics_ set_ message_ ttl - persistent_
topics_ set_ offload_ policies - persistent_
topics_ set_ persistence - persistent_
topics_ set_ publish_ rate - persistent_
topics_ set_ replicated_ subscription_ status - persistent_
topics_ set_ replication_ clusters - persistent_
topics_ set_ replicator_ dispatch_ rate - persistent_
topics_ set_ retention - persistent_
topics_ set_ schema_ compatibility_ strategy - persistent_
topics_ set_ schema_ validation_ enforced - persistent_
topics_ set_ shadow_ topics - persistent_
topics_ set_ subscribe_ rate - persistent_
topics_ set_ subscription_ dispatch_ rate - persistent_
topics_ set_ subscription_ level_ dispatch_ rate - persistent_
topics_ set_ subscription_ types_ enabled - persistent_
topics_ skip_ all_ messages - Completely clears the backlog on the subscription.
- persistent_
topics_ skip_ messages - persistent_
topics_ terminate - persistent_
topics_ terminate_ partitioned_ topic - persistent_
topics_ trigger_ offload - persistent_
topics_ trim_ topic - persistent_
topics_ truncate_ topic - The truncate operation will move all cursors to the end of the topic and delete all inactive ledgers.
- persistent_
topics_ unload_ topic - persistent_
topics_ update_ partitioned_ topic - It increments partitions of existing partitioned-topic
- persistent_
topics_ update_ properties - persistent_
topics_ update_ subscription_ properties